<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ExLayerCustomProperty</name>
    <message>
        <location filename="../ExLayerCustomProperty.js" line="+43"/>
        <source>Added custom property &apos;MyCustomProperty&apos; to layer &apos;0&apos;.</source>
        <translation>Добавлено пользовательское свойство &apos;MyCustomProperty&apos; к слою &apos;0&apos;.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add Custom Property to a Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add custom property to a layer</source>
        <translation type="vanished">Добавить пользовательское свойство к слою</translation>
    </message>
</context>
</TS>
